@@ -14,17 +14,17 @@ import requests
 HERE = os.path.dirname(os.path.abspath(__file__))
 
 
-@pytest.fixture
+@pytest.fixture()
 def port():
     return 9999
 
 
-@pytest.fixture
+@pytest.fixture()
 def token():
     return hexlify(os.urandom(4)).decode("ascii")
 
 
-@pytest.fixture
+@pytest.fixture()
 def auth_header(token):
     return {"Authorization": "token %s" % token}
 
@@ -32,7 +32,7 @@ def auth_header(token):
 def wait_up(url, interval=0.1, check=None):
     while True:
         try:
-            r = requests.get(url)  # noqa
+            r = requests.get(url)
         except Exception:
             if check:
                 assert check()
@@ -42,7 +42,7 @@ def wait_up(url, interval=0.1, check=None):
             break
 
 
-@pytest.fixture
+@pytest.fixture()
 def launch_instance(request, port, token):
     def _run_in_subprocess(argv=None, add_token=True):
         argv = argv or []
@@ -86,11 +86,11 @@ def launch_instance(request, port, token):
     return _run_in_subprocess
 
 
-@pytest.fixture
+@pytest.fixture()
 def fetch(port, auth_header):
     def _get(endpoint):
         url = f"http://127.0.0.1:{port}" + endpoint
-        return requests.get(url, headers=auth_header)  # noqa
+        return requests.get(url, headers=auth_header)
 
     return _get
 
